@@ -219,6 +219,8 @@ def plot_image(
     plot_kws.setdefault("linewidth", 0.0)
     plot_kws.setdefault("rasterized", True)
     log = "norm" in plot_kws and plot_kws["norm"] == "log"
+    
+    f = f.copy()
     if fill_value is not None:
         f = np.ma.filled(f, fill_value=fill_value)
     if thresh is not None:
@@ -425,7 +427,7 @@ def corner(
         for i in range(n):
             heights, _edges = np.histogram(data[:, i], bins, limits[i], density=True)
             heights = heights / np.max(heights)
-            _centers = psi.get_bin_centers(_edges)
+            _centers = utils.bin_centers(_edges)
             edges.append(_edges)
             centers.append(_centers)
             if diag:
@@ -570,7 +572,7 @@ def _annotate_matrix_slice(axes, islice, iview, dims, height=0.2,
     return axes    
 
 
-def matrix_slice(
+def slice_matrix(
     f, 
     axis_view=None, 
     axis_slice=None, 
@@ -1486,7 +1488,7 @@ def interactive_proj2d_discrete(
         yedges = np.histogram_bin_edges(_X[:, 1], bins=_nbins, range=limits[axis_view[1]])
         edges = [xedges, yedges]
         im, _ = np.histogramdd(_X, bins=edges)
-        centers = [psi.get_bin_centers(e) for e in edges]
+        centers = [utils.bin_centers(e) for e in edges]
         
         # Plot image.
         plot_kws['norm'] = 'log' if log else None
@@ -1508,4 +1510,4 @@ def interactive_proj2d_discrete(
         kws[f"slider{i}"] = slider
     kws["nbins"] = nbins
     kws["nbins_plot"] = nbins_plot
-    return interactive(update, **kws)
\ No newline at end of file
+    return interactive(update, **kws)
